.. _tutorial_main:

=========
Tutorials
=========
Here you'll find a set of tutorials to introduce concepts and tools available
in the ``vivarium`` framework.

Before digging into the tutorials, please walk through the
:doc:`getting started <getting_started>` guide.  It will help you set up a
Python package where you'll build your model components.

.. toctree::
   :maxdepth: 2
   :glob:

   *
   */index
